///////////////////////////////////////////////////////////////////////////////////////////////////////////////
//=============================================================================================================
// INTRODUCTION
//=============================================================================================================
//  Project/Example: Shake Sensor
//  Purpose: A simple example which demostrates how to use the shake sensor.
//  License: GNU General Public License v3
//  Link: http://wiki.microduinoinc.com/Sensor-Shake
// 
//  Author(s): Microduino
//  E-mail(s): support at microduino.cc
//
//  Version: 1.0
//  Date: 2017/07/13
//  Notes: Initial version
//
//=============================================================================================================
// REQUIRED HARDWARE
//=============================================================================================================
//  COMPATIBLE KITS
//    [ ] 101 Basic Kit
//    [ ] 201 Advanced Kit
//    [*] 301 Expert Kit
//    [ ] 102 Basic Kit
//    [ ] 202 Advanced Kit
//    [ ] 302 Expert Kit
//    [ ] Itty Bitty City Kit
//=============================================================================================================
//  MODULES
//    [1] Core, Core+, CoreUSB -OR- CoreRF
//    [1] mBattery -OR- USBTTL (neither needed when using CoreUSB)
//    [1] Sensor Hub
//  SENSORS/TRINKETS
//    [1] Shake Sensor
//    [1] Sensor Cable
//  OTHER
//    [1] MicroUSB Cable
//=============================================================================================================
// SETUP
//=============================================================================================================
//  NOTE: When connecting sensor wires, push on the plastic connector and not on the wires. 
//          Pushing on the wire can damage them.
//
//  1.  Connect the Shake Sensor to the Sensor Hub on Pin 6/7
//  2.  Stack the Sensor Hub on a core module.
//  3.  Stack the core module on a programmer (if not a CoreUSB).
//  4.  Upload this program by hitting the "upload" button.
//
//=============================================================================================================
// USAGE
//=============================================================================================================
//  Open "Serial Monitor" (magnifying glass on top right of Software).
//  Set baud to "9600" on bottom right of "Serial Monitor" window.
//  Check autoscroll on bottom left of "Serial Monitor" window.
//  The time will print out as t=#######, this is to simply show that the code is looping.
//  Move the Shake Sensor around. This will trigger "SHAKE DETECTED!" output.
//  Wait a few moments for the Shake Sensor to settle down.
//
//=============================================================================================================
// TWEAKING
//=============================================================================================================
// 
//=============================================================================================================
// NOTES
//=============================================================================================================
//  When using digitalRead() Shake Sensor produces a HIGH value with shaking is detected. Otherwise, the 
//    sensor produces a LOW value when there is no shaking. There is a settling time for the sensor to 
//    normalize after a shake.
//  *More info at: http://wiki.microduinoinc.com/Sensor-Shake
///////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Defines the pin the the Shake Sensor is connected to.
//Read more about pin access at: http://wiki.microduinoinc.com/MCookie-Hub
const int SHAKE_SENSOR_PIN = 6;

void setup() {
  Serial.begin(9600);

  //Set the pin to input mode.
  pinMode(SHAKE_SENSOR_PIN, INPUT);
}

void loop() {
  //Output the time
  Serial.print("t=");
  Serial.print(millis());

  if(digitalRead(SHAKE_SENSOR_PIN) == HIGH){        //Check if Shake Sensor detects shakes.
    //Shake detected
    Serial.print("\tSHAKE DETECTED!");
  }
  else if(digitalRead(SHAKE_SENSOR_PIN) == LOW){    //Check if Shake Sensor do not detect shakes.
    //Shake not detected
  }

  Serial.println("");                               //End this line of output, so not everything is in a single line.

  //10 ms delay as to not spam output.
  delay(10);
}
